@@ -1,3 +1,11 @@
+vov_params <- function() {
+  c(
+    '@param ui A UI element',
+    '@param duration Duration of animation; Enter word: "fast" = 800 milliseconds, "faster" = 500 milliseconds, "fastest" = 300 milliseconds, "slow" = 2 seconds, "slower" = 3 seconds, "slowest" = 4 seconds',
+    '@param delay Delay in seconds before animation starts; Enter value: 0 - 5'
+  )
+}
+
 #' Use the vov package
 #'
 #' @description Enables vov by including the CSS file necessary for the
@@ -42,10 +50,7 @@ run_demo <- function() {
 #'
 #' @description Animation to fade in a UI element from the bottom left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -73,10 +78,7 @@ fade_in_bottom_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element from the bottom right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -104,10 +106,7 @@ fade_in_bottom_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element downward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -135,10 +134,7 @@ fade_in_down <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -166,10 +162,7 @@ fade_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -197,10 +190,7 @@ fade_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element from the top left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -228,10 +218,7 @@ fade_in_top_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element from the top right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -259,10 +246,7 @@ fade_in_top_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element upward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -290,10 +274,7 @@ fade_in_up <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade in a UI element.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -322,10 +303,7 @@ fade_in <- function(ui, duration = NULL, delay = NULL) {
 #' @description Animation to fade out (disappear) a UI element from the
 #' bottom left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -354,10 +332,7 @@ fade_out_bottom_left <- function(ui, duration = NULL, delay = NULL) {
 #' @description Animation to fade out (disappear) a UI element from the
 #' bottom right
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -385,10 +360,7 @@ fade_out_bottom_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade out (disappear) a UI element downward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -416,10 +388,7 @@ fade_out_down <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade out (disappear) a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -447,10 +416,7 @@ fade_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade out (disappear) a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -479,10 +445,7 @@ fade_out_right <- function(ui, duration = NULL, delay = NULL) {
 #' @description Animation to fade out (disappear) a UI element from the top
 #' left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -511,10 +474,7 @@ fade_out_top_left <- function(ui, duration = NULL, delay = NULL) {
 #' @description Animation to fade out (disappear) a UI element from the top
 #' right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -542,10 +502,7 @@ fade_out_top_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade out (disappear) a UI element upwards.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -573,10 +530,7 @@ fade_out_up <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to fade out (disappear) a UI element.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -604,10 +558,7 @@ fade_out <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to roll in a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -635,10 +586,7 @@ roll_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to roll in a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -666,10 +614,7 @@ roll_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to roll out (disappear) a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -697,10 +642,7 @@ roll_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to roll out (disappear) a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -728,10 +670,7 @@ roll_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to shake a UI element vertically.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -759,10 +698,7 @@ shake_vertical <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to shake a UI element horizontally.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -790,10 +726,7 @@ shake_horizontal <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to blur in a UI element.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -821,10 +754,7 @@ blur_in <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to blur out (disappear) a UI element.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -852,10 +782,7 @@ blur_out <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide in a UI element downward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -883,10 +810,7 @@ slide_in_down <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide in a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -914,10 +838,7 @@ slide_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide in a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -945,10 +866,7 @@ slide_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide in a UI element upward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -976,10 +894,7 @@ slide_in_up <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide in a UI element downward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1007,10 +922,7 @@ slide_out_down <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide out (disappear) a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1038,10 +950,7 @@ slide_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide out (disappear) a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1069,10 +978,7 @@ slide_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to slide out (disappear) a UI element upward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1100,10 +1006,7 @@ slide_out_up <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to throb a UI element outward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1131,10 +1034,7 @@ throb <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to throb a UI element inward.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1162,10 +1062,7 @@ i_throb <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to swivel a UI element horizontally.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1193,10 +1090,7 @@ swivel_horizontal <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to swivel a UI element horizontally, twice.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1224,10 +1118,7 @@ swivel_horizontal_double <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to swivel a UI element vertically.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1255,10 +1146,7 @@ swivel_vertical <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to swivel a UI element vertically, twice.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1286,10 +1174,7 @@ swivel_vertical_double <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to wheel in a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1317,10 +1202,7 @@ wheel_in_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to wheel in a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1348,10 +1230,7 @@ wheel_in_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to wheel out (disappear) a UI element from the left.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1379,10 +1258,7 @@ wheel_out_left <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to wheel out (disappear) a UI element from the right.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
@@ -1410,10 +1286,7 @@ wheel_out_right <- function(ui, duration = NULL, delay = NULL) {
 #'
 #' @description Animation to flash a UI element.
 #'
-#' @param ui A UI element
-#' @param duration Duration of animation, one of fastest, faster, fast, slow,
-#' slower, slowest
-#' @param delay Delay in seconds before animation starts
+#' @eval vov_params()
 #'
 #' @examples
 #' if (interactive()) {
